
import java.sql.DriverManager;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.sql.Statement;
import java.sql.Timestamp;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.Calendar;
import java.util.List;
import java.util.TimeZone;
import java.sql.Connection;

/**
 *
 * @author cyang
 */
public class TimeZoneTest {

    public static void main(String[] args) {
        String userTimeZone = System.getProperty("user.timezone");
        System.out.println("userTimezone: " + userTimeZone);
        String userCountry = System.getProperty("user.country");
        System.out.println("userCountry: " + userCountry);
        String javaHome = System.getProperty("java.home");
        System.out.println("javaHome: " + javaHome);

        TimeZone tz = TimeZone.getDefault();

        System.out.println("tz" + tz);


        System.out.println("tz display name: " + tz.getDisplayName());
        System.out.println("tz id: " + tz.getID());


        testDateTimeColumnRead();
        testDateTimeColumnInRange();

    }


    private static void testDateTimeColumnRead() {
		logger_debug(System.getProperty("line.separator"));
		logger_debug("================= getAdEndTimeByJdbc ====================");
        getAdStartEndTimeByJDBC();

    }
    private static void testDateTimeColumnInRange() {
//        String dateTimeString = "2010-12-20T23:59:59.999";
        String dateTimeString = "2010-12-21T00:00:01.000";
        String timezone = "GMT";

		logger_debug(System.getProperty("line.separator"));
		logger_debug("================= Print out created calendar and timestamp ====================");
        Timestamp timestamp = getTimestamp(dateTimeString, timezone);
        logger_debug("Created timestamp: " + timestamp);

		logger_debug(System.getProperty("line.separator"));
        logger_debug("================= isDateInRangeByJdbc ====================");
        isDateInRangeByJdbc(timestamp);
    }



    private static Timestamp getTimestamp(String dateTimeString, String timezone) {
        SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd'T'HH:mm:ss.SSS");
        sdf.setTimeZone(TimeZone.getTimeZone(timezone));

        java.util.Date date = null;

        try {
            date = sdf.parse(dateTimeString);

        } catch (ParseException pex) {
            logger_debug("unexpected Date parsingException: ", pex);
            throw new RuntimeException(pex);
        }

        Calendar cal = Calendar.getInstance(TimeZone.getTimeZone(timezone));
        cal.setTime(date);
        logger_debug("created calendar: " + cal);

        //java.sql.Timestamp timestamp = new java.sql.Timestamp(cal.getTimeInMillis());
        java.sql.Timestamp timestamp = new java.sql.Timestamp(date.getTime());
        return timestamp;


    }



    private static Connection getConnection() {
        Connection conn = null;
        try {
            Class.forName("com.mysql.jdbc.Driver");
            conn = DriverManager.getConnection("jdbc:mysql://10.37.2.24:3306/campaign_mgr?useTimezone=true&noTimezoneConversionForTimeType=true", "ad", "ad");
//            conn = DriverManager.getConnection("jdbc:mysql://10.37.2.24:3306/campaign_mgr?useTimezone=true&serverTimezone=GMT&noTimezoneConversionForTimeType=true", "ad", "ad");




        } catch (SQLException sqx) {
            System.out.println("Can't obtain connection from driver class: " + sqx.getMessage());
            sqx.printStackTrace();
            throw new RuntimeException(sqx);
        } catch (ClassNotFoundException cnx) {
            System.out.println("Can't obtain connection from driver class: " + cnx.getMessage());
            cnx.printStackTrace();
            throw new RuntimeException(cnx);
        }

        if (conn == null) {
            System.out.println("Can't obtain connection from the driver ");
        }
        return conn;

    }

    private static void getAdStartEndTimeByJDBC() {
        Connection conn = null;
        PreparedStatement pst = null;
        ResultSet rs = null;

        try {

            conn = getConnection();
            pst = conn.prepareStatement("select * from ad where id=1");


            rs = pst.executeQuery();


            while (rs.next()) {
                java.sql.Timestamp endDate = rs.getTimestamp("ad_end_date");
                System.out.println("endDate: " + endDate);
            }



        } catch (Exception ex) {

            System.out.println("Exception during querying ad: " + ex.getMessage());
            ex.printStackTrace();
            throw new RuntimeException(ex);


        } finally {
            closeResultSet(rs);
            closeStatement(pst);
            closeConnection(conn);
        }


    }

    private static void closeResultSet(ResultSet rs) {
        if (rs != null) {
            try {
                rs.close();
            } catch (SQLException sqx) {
                System.out.println("Error in close ResultSet: ");
                sqx.printStackTrace();
                // do nothing
            }
        }
    }

    private static void closeStatement(Statement stmt) {
        if (stmt != null) {
            try {
                stmt.close();
            } catch (SQLException sqx) {
                System.out.println("Error in close Statement: ");
                sqx.printStackTrace();
                // do nothing
            }
        }
    }

    private static void closeConnection(Connection conn) {
        if (conn != null) {
            try {
                conn.close();
            } catch (SQLException sqx) {
                System.out.println("Error in close Connection: ");
                sqx.printStackTrace();
                // do nothing
            }
        }
    }

    private static void logger_debug(String msg, Exception ex) {
        System.out.println(msg);
        ex.printStackTrace();
        throw new RuntimeException(ex);
    }

    private static void logger_debug(Object msg) {
        System.out.println(msg.toString());

    }


    private static void isDateInRangeByJdbc (java.sql.Timestamp timestamp) {
        Connection conn = null;
        PreparedStatement pst = null;
        ResultSet rs = null;


        try {

            conn = getConnection();

            pst = conn.prepareStatement("select * from ad where ad_end_date>=?");

            pst.setTimestamp(1, timestamp);
            rs = pst.executeQuery();

            int adId = -1;
            Timestamp startDate = null;
            Timestamp endDate = null;

            while (rs.next()) {
                adId = rs.getInt("id");
                startDate = rs.getTimestamp("ad_start_date");
                endDate = rs.getTimestamp("ad_end_date");

                logger_debug("adId: " + adId);
                logger_debug("adStartDate: " + startDate);
                logger_debug("adEndDate: " + endDate);

            }



        } catch (Exception ex) {

            logger_debug("Exception during querying ad: ", ex);


        } finally {
            closeResultSet(rs);
		    closeStatement(pst);
            closeConnection(conn);

        }

    }





}

